.. _tutorials:

=========
Tutorials
=========

Video Tutorials
===============

.. _introqmlearn:

.. dropdown:: 0. QMLearn Installation

    ..  youtube:: aG5vqBpNfZw
       :align: center
       :aspect: 16:9


.. dropdown:: 1. Intro to QMLearn

    ..  youtube:: zRBijIt1Prs
       :align: center
       :aspect: 16:9

.. _installqmlearn:

.. dropdown:: 2. Creating a Database

    ..  youtube:: Ngiw-6-RoiE
       :align: center
       :aspect: 16:9


.. dropdown:: 3. Creating a QMModel: Fitting the Model and Predicting

    ..  youtube:: M2hEjksZATM
       :align: center
       :aspect: 16:9

.. dropdown:: 4. Using a QMModel: Performing Geometry Optimization

    ..  youtube:: IDpilj9CwHI
       :align: center
       :aspect: 16:9

.. _jupyternotebook:

Jupyter-Notebook Tutorials
==========================


`Creating a database <1_create_training.ipynb>`_.
----------------------------------------------------


`Creating a QMModel: Fitting the Model and Predicting <3_predict_model.ipynb>`_.
--------------------------------------------------------------------------------


`Using a QMModel: Performing Geometry Optimization <2_test_qml.ipynb>`_.
------------------------------------------------------------------------
